from setuptools import setup

setup(name='dai175_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['dai175_probability'],
      author = 'Daisuke Ohba',
      author_email = 'dai175dai@gmail.com',
      zip_safe=False)
